<?php 

/**
 * The functions that enhance Plakob.
 *
 * @name    Plakob
 * @version 1.0
 * @link    http://www.mattread.com/projects/wp-themes/lucid/
 * @author  Matt Read <http://www.mattread.com/>
 *
 */

load_theme_textdomain('plakob');

function search_static($where) {
	if (is_search())
		$where = preg_replace("'\(post_status = \"publish\".*'", "(post_status = 'static' OR post_status = 'publish')", $where);
	return $where;
}

function search_per_page(&$that) {
	if ($_GET['posts_per_page'])
		$that->query_vars['posts_per_page'] = intval($_GET['posts_per_page']);
}
add_filter('posts_where_paged', 'search_static');
add_action('pre_get_posts', 'search_per_page');

function bread_crumb() {
	global $year, $month, $monthnum, $day, $post, $wpdb;
	if(is_page() || is_attachment()) {
		if (!$post->post_parent) return false;
		$parent = get_page($post->post_parent);
		
		$bc = array(get_the_title($post->ID));
		while ($parent) {
			$bc[] = '<a href="'. get_permalink($parent->ID) .'">'. get_the_title($parent->ID) .'</a>';
			if ($parent->post_parent) $parent = get_page($parent->post_parent);
			else break;
		}
		
		echo '<p style="font-size:.9em;">';
		foreach (array_reverse($bc) as $b) {
			echo " &#187; $b";
		}
		echo '</p>';
	}
	elseif (is_single()) {
		$my_month =  ($monthnum>9)?$monthnum:'0'.$monthnum;
		echo '<p style="font-size:.9em;">&#187; <a href="/archive/">Blog Archive</a>';
		
		if ($year)
			echo " &#187; <a href=\"". get_year_link($year) ."\">$year</a>";
		if ($monthnum)
			echo " &#187; <a href=\"". get_month_link($year, $monthnum) ."\">{$month[$my_month]}</a>";
		if ($day)
			echo " &#187; <a href=\"". get_day_link($year, $monthnum, $day) ."\">$day</a>";
		
		echo " &#187; ". get_the_title() ."</p>";
	}
}

function the_content_part($len = 200) {
	echo substr(strip_tags(get_the_content()), 0, $len) .' ... ';
}

function search_term() {
	echo htmlspecialchars(get_query_var('s'));
}

function back_to_top() {
	echo '<p class="back-top"><a href="#top" title="'. __('Back to the top of the page', 'plakob') .'">'. __('Top', 'plakob') .'</a></p>';
}

function single_add_page_number($title) {
	global $page;
	if ($page > 1)
		$title = sprintf(__('%1$s, Page %2$s', 'plakob'), $title, $page);
	return $title;
}
add_filter('the_title', 'single_add_page_number');

function highlight_comment() {
	global $comment, $user_ID, $comment_author_email, $post;
	
	if ( ($comment->comment_author_email) AND (get_comment_type() == 'comment') ) {
		if ( $comment->user_id == $post->post_author ) //highlight author
			echo ' class="author-comment"';
		
		elseif ( $comment->user_id == $user_ID ) //highlight user if not author
			echo ' class="user-comment"';
		
		elseif ( $comment->comment_author_email == $comment_author_email ) //highlight commenter if not user
			echo ' class="user-comment"';
	}
}

function __comments_link() {
	if (comments_open()) {
		echo ' | <a href="';
		comments_link();
		echo '" title="'. __('View or leave a Comment', 'plakob') .'">';
		comments_number(__('No Comments', 'plakob'), __('1 Comment', 'plakob'), __('% Comments', 'plakob'));
		echo '</a>';
	}
	else
		_e(' | Comments Closed', 'plakob');
}

function post_relative_links() {
	if (!is_single() || is_attachment()) return false;
	
	echo "<h3>". __('Relative Links', 'plakob') ."</h3><p>";
	next_post_link('%link | ', __('&#171;NEXT', 'plakob'));
	
	$array = explode('/', trailingslashit($_SERVER['REQUEST_URI']));
	array_pop($array);
	array_pop($array);
	echo '<a href="'. trailingslashit(implode('/', $array)) .'">'. __('UP', 'plakob') .'</a>';
	
	previous_post_link(' | %link', __('PREV&#187;', 'plakob'));
	echo "</p>";
}
add_action('wp_meta', 'post_relative_links');

function archives_header($before='', $after='') {
	global $post, $month;
	static $previous_date = false;

	$monthnum = mysql2date('m', $post->post_date);
	$year = mysql2date('Y', $post->post_date);
	$date = $year.$monthnum;
	
	if ($date != $previous_date) {
		$output .= $month[$monthnum] .' '. $year;
	}
	$previous_date = $date;
	
	if (!empty($output)) {
		$output = $before . $output . $after;
		echo $output;
	}
}

function archive_start() {
	global $paged, $posts_per_page;
	
	echo ($paged > 1) ? ($paged * $posts_per_page + 1) - ($posts_per_page) : 1;
}

function archive_header() {
	global $posts, $posts_per_page, $month, $wpdb, $wp_query;
	
	$monthnum = (get_query_var('monthnum')<10)?'0'.get_query_var('monthnum'):get_query_var('monthnum');
	
	# Look for archive pages, and display special header
	if (is_category()) {
		$feed_link = get_category_rss_link(false, get_query_var('cat'), '');
		$archive = sprintf(__('%1$s Category', 'plakob'), single_cat_title('', false));
	}
	
	elseif (is_day()) {
		$archive = sprintf(__('%1$s %2$s, %3$s Archives', 'plakob'), $month[$monthnum], get_query_var('day'), get_query_var('year'));
	}
	
	elseif (is_month()) {
		$archive = sprintf(__('%1$s, %2$s Archives', 'plakob'), $month[$monthnum], get_query_var('year'));
	}
	
	elseif (is_year()) {
		$archive = sprintf(__('%1$s Archives', 'plakob'), get_query_var('year'));
	}
	
	elseif (is_author()) {
		$authordata = get_userdata($posts[0]->post_author);
		$feed_link = get_author_rss_link(false, $authordata->ID, $authordata->user_nicename);
		$archive = sprintf(__('%1$s Posts By %2$s', 'plakob'), get_usernumposts($posts[0]->post_author), '<a href="' .$authordata->user_url. '">'. $authordata->display_name.'</a>');
	}
	
	elseif (is_search()) {
		if ($posts)
			$archive = sprintf(__('Search Results for <em>%1$s</em>', 'plakob'), htmlspecialchars(get_query_var('s')));
		else
			$archive = __('No Results Found', 'plakob');
	}
	print_archive_header($archive, $feed_link);
}

function print_archive_header($archive, $feed_link = '') {
	global $paged, $posts_per_page, $posts, $wpdb, $request;
	
	$feed_image = get_bloginfo('template_directory') .'/images/xml.png';
	
	if (is_paged())
		$archive = sprintf(__('%1$s, Page %2$s', 'plakob'), $archive, get_query_var('paged'));
	
	preg_match('#FROM\s(.*)\sGROUP BY#siU', $request, $matches);
	$numresults = $wpdb->get_var("SELECT COUNT(ID) AS count FROM $matches[1]");
	$start = ($paged > 1) ? ($paged * $posts_per_page + 1) - ($posts_per_page) : 1;
	$end = $start + count($posts) - 1;
	
	$sub = sprintf(__('Showing posts %1$s - %2$s of %3$s', 'plakob'), $start, $end, $numresults);
	
	echo "<h2>$archive";
	if ($feed_link)
		echo " <a href=\"$feed_link\" class=\"no-border\"><img src=\"$feed_image\"></a>";
	echo "</h2><p class=\"post-meta\">$sub</p>";
}

function posts_pages_link() {
	global $request, $posts_per_page, $wpdb, $max_num_pages, $paged;
	if ( !is_single() ) {
		if ( !isset($max_num_pages) ) {
			preg_match('#FROM\s(.*)\sGROUP BY#siU', $request, $matches);
			$fromwhere = $matches[1];
			$numposts = $wpdb->get_var("SELECT COUNT(DISTINCT ID) FROM $fromwhere");
			$max_num_pages = ceil($numposts / $posts_per_page);
		}
		for ($i=1; $i<=$max_num_pages; $i++) {
			if ($i == $paged)
				$links .= " <strong>$i</strong> ";
			else
				$links .= " <a href=\"". get_pagenum_link($i) ."\">$i</a> ";
		}
		return $links;
	}
}

function __posts_nav_link() {
	posts_nav_link(' ... '. posts_pages_link() .' ... ', __('&#171; Previous Page', 'plakob'), __('Next Page &#187;', 'plakob'));
}

function is_current($test) {
	global $post;
	$current = false;
	switch ($test) {
		case 'home':
			if (is_home()) $current = true;
			break;
		case 'archive':
			if (is_archive() || is_single() || is_page($test)) $current = true;
			break;
		default:
			if (is_page($test)) $current = true;
			elseif ($post->post_parent) {
				$loop = true;
				$page_id = $post->post_parent;
				while ($loop) {
					$parent = get_page($page_id);
					if ($parent->post_name == $test) { $current = true; break; }
					if (!$parent->post_parent) $loop = false;
					$page_id = $parent->post_parent;
				}
			}
			break;
	}
	if ($current)
		echo ' class="current"';
	return;
}

function header_meta() {
	if (is_single()) {
		$next_post = get_next_post();
		$previous_post = get_previous_post();
		echo "\n\t".'<link rel="next" title="'. __('Next Post') .'" href="'.get_permalink($next_post->ID).'" />';
		echo "\n\t".'<link rel="previous" title="'. __('Previous Post') .'" href="'.get_permalink($previous_post->ID).'" />';
	}
	else if (is_archive() || is_home() || is_search()) {
		echo "\n\t".'<link rel="next" title="'. __('Next Page') .'" href="'; next_posts(); echo '" />';
		echo "\n\t".'<link rel="previous" title="'. __('Previous Page') .'" href="'; previous_posts(); echo '" />';
	}
	echo "\n\t";
}
add_action('wp_head', 'header_meta');

function google_ads($after_post = false) {
	// insert google ads here
}

function google_ads_ff() {
	// insert firefox google ads here
}

function paypal() {
	// insert paypal ads here
}

?>